%% Load models
load Example1
F_1channel = Vernan(n,Q,rules,D,rho,finit);

load Example3
F4 = F; clear F;
T4 = double(T); clear T;
W4 = W; clear W;
M4 = double(M); clear M;

load Example2
F28 = F; clear F;
T28 = double(T); clear T;
W28 = W; clear W;
M28 = double(M); clear M;

C = 10*rand(24,1); %randomly assign values to the 24 model rate constants
                   %in the interval (0,10)

%% Reconstruct 28 component system states from 4 component system states
F4to28 = zeros(size(F4,1),28);
for i = 1:size(F4,1)
    for j = 1:4
        F4to28(i,(1:2) + 2*(j-1)) = F_1channel(F4(i,j),1:2);
        F4to28(i,(9:10) + 2*(j-1)) = F_1channel(F4(i,j),3:4);
        F4to28(i,(17:18) + 2*(j-1)) = F_1channel(F4(i,j),5:6);
        F4to28(i,25 + j-1) = F_1channel(F4(i,j),7);
    end
end

% reconstructed 28 component system states need to be canonized in the same
% way as the 28 component model
[Type,Tsize,Trelab] = IDComponentTypes(n,Q);
[~,~,Gtilde] = GenerateCharacteristicGraph(finit,Type,rules,D);
[d,v,e,c] = SetupNautyGraph_sparse(Gtilde);
[S,vstab] = CallNauty_sparse(d,v,e,c);
S = S(:,1:28);
[base,~,~,U] = SchreierSims(S,vstab);
%warning! the loop below requires 304590 iterations and will take some time
%(~tens of minutes) to run
for i = 1:size(F4,1)
    F4to28(i,:) = FindCanonRep(F4to28(i,:),d,v,e,c,base,U);
end

%% Encode and sort system states
[numdigits,startofdigit,endofdigit] = GenerateCodingScheme(finit,Tsize);
[~,ixF28] = sort(Encode(F28,Tsize,Trelab,numdigits,startofdigit, ...
              endofdigit));
[~,ixF4to28] = sort(Encode(F4to28,Tsize,Trelab,numdigits, ...
                    startofdigit,endofdigit));
F28 = F28(ixF28);
F4to28 = F4to28(ixF4to28);

%need to update the indices in T for the two models to account for the new
%indexing of system states
ixF28(ixF28) = 1:length(ixF28);
T28 = ixF28(T28);
ixF4to28(ixF4to28) = 1:length(ixF4to28);
T4 = ixF4to28(T4);

%% Construct transition matrices for the 28 and 4 component versions of 
%  the model and test their equivalence
A28 = sparse(T28(:,2),T28(:,1),M28.*C(W28));
A4 = sparse(T4(:,2),T4(:,1),M4.*Cprime(W4,1).*C(Cprime(W4,2)));
if isequal(A28,A4)
    disp('Matrices are equal');
else
    disp('Matrices are not equal');
end