function [tf] = issubmultiset(A,mA,B,mB)
%ISSUBMULTISET test whether multiset (A,mA) is a submultiset of multiset 
%(B,mB).
%
% INPUT:  A and B are numeric vectors representing underlying sets.
%
%         mA and mB are numeric vectors of length length(A) and length(B),
%         respectively, representing the multiplicity functions of A and B.
%
% OUTPUT: tf is a logical variable which is true when there are at least as
%         many instances of the elements of A in the multiset (B,mB) as 
%         there are in the multiset (A,mA), and false otherwise.
%
% Author:   Scott Bugenhagen
% Contact:  sbugenha@mcw.edu
% Date:     8/30/11
%
% References: 
% 1. http://en.wikipedia.org/wiki/Multiset

if ~issorted(A)
    [A,ix] = sort(A);
    mA = mA(ix);
end
if ~issorted(B)
    [B,ix] = sort(B);
    mB = mB(ix);
end
loc = ismembc2(A,B);
if ~all(loc)
    tf = false;
elseif any(mB(loc) - mA < 0)
    tf = false;
else
    tf = true;
end
end