function [C,mC] = multisetdiff(A,mA,B,mB)
%MULTISETDIFF computes the multiset difference (A,mA)\(B,mB) of multisets 
%(A,mA) and (B,mB). The multiset difference is the zero-truncated 
%subtraction of multiplicity functions mA and mB.
%
% INPUT:  A and B are numeric vectors representing underlying sets of
%         elements.
%
%         mA and mB are numeric vectors of lengths length(A) and length(B),
%         respectively, representing multiplicity functions of the
%         underlying sets such that mA(i) and mB(i) are the multiplicities
%         of elements A(i) and B(i), respectively.
%
% OUTPUT: (C,mC) is the multiset given by (A,mA)\(B,mB). That is, it is the
%         multiset having the multiplicity function given by the 
%         zero-truncated subtraction of the multiplicity functions mA and
%         mB.
%
% Author:   Scott Bugenhagen
% Contact:  sbugenha@mcw.edu
% Date:     8/30/2011
%
% References: 
% 1. http://en.wikipedia.org/wiki/Multiset

[tf,loc] = ismember(B,A);
mC = mA;
mC(loc(tf)) = mA(loc(tf)) - mB(tf);
C = A(mC > 0);
mC = mC(mC > 0);
end